package Perinci::To::POD::I18N;

use base 'Perinci::To::PackageBase::I18N';

our $VERSION = '0.22'; # VERSION

1;
# ABSTRACT: Project class for Perinci::To::POD

__END__
=pod

=head1 NAME

Perinci::To::POD::I18N - Project class for Perinci::To::POD

=head1 VERSION

version 0.22

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

